toga
====

A meta-package for installing the `Toga widget toolkit`_.

This package installs the `toga-core <https://pypi.org/project/toga-core>`__ library,
plus a different Toga backend depending the platform where it is installed:

* `toga-cocoa <https://pypi.org/project/toga-cocoa>`__ on macOS
* `toga-gtk <https://pypi.org/project/toga-gtk>`__ on Linux and FreeBSD
* `toga-winforms <https://pypi.org/project/toga-winforms>`__ on Windows

Backends are also available for `Android <https://pypi.org/project/toga-android>`__,
`iOS <https://pypi.org/project/toga-iOS>`__, `single-page web apps
<https://pypi.org/project/toga-web>`__, and `testing
<https://pypi.org/project/toga-dummy>`__; however, these must be installed manually.

Toga requires **Python 3.8** or newer. It does not support Python 2. Some platforms have
additional prerequisites; see the `Toga platform guide
<https://toga.readthedocs.io/en/stable/reference/platforms/index.html>`__ for details.

For more details, see the `Toga project on Github`_.

.. _Toga widget toolkit: https://beeware.org/toga
.. _Toga project on Github: https://github.com/beeware/toga

Community
---------

Toga is part of the `BeeWare suite`_. You can talk to the community through:

* `@beeware@fosstodon.org on Mastodon`_
* `Discord`_
* The Toga `Github Discussions forum`_

We foster a welcoming and respectful community as described in our
`BeeWare Community Code of Conduct`_.

.. _BeeWare suite: https://beeware.org
.. _@beeware@fosstodon.org on Mastodon: https://fosstodon.org/@beeware
.. _Discord: https://beeware.org/bee/chat/
.. _Github Discussions forum: https://github.com/beeware/toga/discussions
.. _BeeWare Community Code of Conduct: https://beeware.org/community/behavior/

Contributing
------------

If you experience problems with this package, `log them on GitHub`_. If you
want to contribute code, please `fork the code`_ and `submit a pull request`_.

.. _log them on Github: https://github.com/beeware/toga/issues
.. _fork the code: https://github.com/beeware/toga
.. _submit a pull request: https://github.com/beeware/toga/pulls
